@@ -52,7 +52,7 @@ if os.path.exists('debian/compat'):
         # Assume that the compat version is set in Build-Depends
         def set_debhelper_compat(control):
             control["Build-Depends"] = ensure_exact_version(
-                control["Build-Depends"],
+                control.get("Build-Depends", ""),
                 "debhelper-compat",
                 "%d" % new_debhelper_compat_version)
             try:
@@ -82,7 +82,7 @@ if os.path.exists('debian/compat'):
 
         def bump_debhelper(control):
             control["Build-Depends"] = ensure_minimum_version(
-                    control["Build-Depends"],
+                    control.get("Build-Depends", ""),
                     "debhelper",
                     "%d~" % new_debhelper_compat_version)
 
@@ -93,7 +93,7 @@ else:
         global current_debhelper_compat_version
         try:
             debhelper_compat_relation = get_relation(
-                control["Build-Depends"], "debhelper-compat")
+                control.get("Build-Depends", ""), "debhelper-compat")
         except KeyError:
             sys.exit(2)
         else:
@@ -148,11 +148,6 @@ def upgrade_to_debhelper_12():
                 'debian/rules: Call dh_missing rather than using dh_install '
                 '--list-missing.')
             return [line, b'dh_missing --fail-missing']
-        if line.startswith(b'dh_systemd_enable'):
-            line = update_line(
-                line, b'dh_systemd_enable', b'dh_installsystemd',
-                'Use dh_installsystemd rather than deprecated '
-                'dh_systemd_enable.')
         return line
 
     update_rules(cb)
@@ -162,6 +157,11 @@ def upgrade_to_debhelper_11():
 
     def cb(line):
         line = dh_invoke_drop_with(line, b'systemd')
+        if line.startswith(b'dh_systemd_enable'):
+            line = update_line(
+                line, b'dh_systemd_enable', b'dh_installsystemd',
+                'Use dh_installsystemd rather than deprecated '
+                'dh_systemd_enable.')
         return line
 
     update_rules(cb)
