@@ -14,7 +14,7 @@ from lintian_brush.rules import (
 
 def bump_debhelper(control):
     control["Build-Depends"] = ensure_minimum_debhelper_version(
-        control["Build-Depends"], "10")
+        control.get("Build-Depends", ""), "10")
     control["Build-Depends"] = drop_dependency(
         control["Build-Depends"],
         "dh-autoreconf")
