@@ -46,7 +46,7 @@ from breezy.transform import revert
 from debian.deb822 import Deb822
 
 
-__version__ = (0, 20)
+__version__ = (0, 21)
 version_string = '.'.join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ['certain', 'possible', None]
 DEFAULT_MINIMUM_CERTAINTY = 'certain'
@@ -543,8 +543,10 @@ def run_lintian_fixer(local_tree, fixer, committer=None,
         raise NoChanges("Certainty of script's changes not high enough")
     if dirty_tracker:
         relpaths = dirty_tracker.relpaths()
+        # Sort paths so that directories get added before the files they
+        # contain (on VCSes where it matters)
         local_tree.add(
-            [p for p in relpaths
+            [p for p in sorted(relpaths)
              if local_tree.has_filename(p) and not
                 local_tree.is_ignored(p)])
         specific_files = [
