@@ -19,12 +19,14 @@
 
 __all__ = ['guess_repository_url', 'determine_browser_url']
 
+import re
 from urllib.parse import urlparse
 
 
 MAINTAINER_EMAIL_MAP = {
     'pkg-javascript-devel@lists.alioth.debian.org': 'js-team',
     'python-modules-team@lists.alioth.debian.org': 'python-team/modules',
+    'python-apps-team@lists.alioth.debian.org': 'python-team/applications',
     'debian-science-maintainers@lists.alioth.debian.org': 'science-team',
     'pkg-perl-maintainers@lists.alioth.debian.org':
         'perl-team/modules/packages',
@@ -63,3 +65,29 @@ def determine_browser_url(url):
     # TODO(jelmer): Add support for branches
     assert parsed_url.netloc == 'salsa.debian.org'
     return 'https://salsa.debian.org%s' % parsed_url.path.rstrip('.git')
+
+
+def salsa_url_from_alioth_url(vcs_type, alioth_url):
+    """Guess the salsa URL from an alioth URL.
+
+    Args:
+      vcs_type: VCS type
+      alioth_url: Alioth URL
+    Returns:
+      Salsa URL
+    """
+    if vcs_type is None:
+        return None
+    # These two regular expressions come from vcswatch:
+    # https://salsa.debian.org/qa/qa/blob/master/data/vcswatch/vcswatch#L165
+    if vcs_type.lower() == 'git':
+        m = "(https?|git)://(anonscm|git).debian.org/(git/)?"
+        if re.match(m, alioth_url):
+            return re.sub(m, 'https://salsa.debian.org/', alioth_url)
+
+    if vcs_type.lower() == 'svn':
+        return alioth_url.replace(
+            'svn://svn.debian.org/pkg-perl/trunk',
+            'https://salsa.debian.org/perl-team/modules/packages')
+
+    return None
