@@ -18,11 +18,13 @@
 """Functions for working with upstream metadata."""
 
 import os
-import shlex
+import re
 import subprocess
 import tempfile
 from urllib.parse import urlparse
 from warnings import warn
+from lintian_brush.vcs import sanitize_url as sanitize_vcs_url
+from lintian_brush.watch import parse_watch_file
 
 
 KNOWN_HOSTING_SITES = [
@@ -80,45 +82,16 @@ def get_python_pkg_info(path, trust_package=False):
         return read_python_pkg_info(td)
 
 
-def parse_watch_file(f):
-    lines = []
-    continued = ''
-    for line in f:
-        if line.startswith('#'):
-            continue
-        if not line.strip():
-            continue
-        if line.rstrip('\n').endswith('\\'):
-            continued += line.rstrip('\n\\') + ' '
-        else:
-            lines.append(continued + line)
-            continued = ''
-    if continued:
-        # Hmm, broken line?
-        lines.append(continued)
-    if not lines:
-        return
-    if not lines.pop(0).startswith('version='):
-        pass  # Hmm, is this actually a real watch file?
-    for line in lines:
-        line = line.strip()
-        parts = shlex.split(line)
-        if parts[0].startswith('opts='):
-            opts = parts[0][len('opts='):]
-            yield [opts] + parts[1:]
-        else:
-            opts = None
-            yield [opts] + parts[0:]
-
-
 def guess_from_debian_watch(path, trust_package):
     with open(path, 'r') as f:
-        for entry in parse_watch_file(f):
-            url = entry[1]
-            if url.startswith('https://') or url.startswith('http://'):
-                repo = guess_repo_from_url(url)
+        wf = parse_watch_file(f)
+        if not wf:
+            return
+        for w in wf:
+            if w.url.startswith('https://') or w.url.startswith('http://'):
+                repo = guess_repo_from_url(w.url)
                 if repo:
-                    yield "Repository", repo, "possible"
+                    yield "Repository", sanitize_vcs_url(repo), "possible"
                     break
 
 
@@ -129,10 +102,11 @@ def guess_from_debian_control(path, trust_package):
     if 'Homepage' in control:
         repo = guess_repo_from_url(control['Homepage'])
         if repo:
-            yield 'Repository', repo, "possible"
+            yield 'Repository', sanitize_vcs_url(repo), "possible"
     if 'XS-Go-Import-Path' in control:
         yield (
-            'Repository', 'https://' + control['XS-Go-Import-Path'],
+            'Repository',
+            sanitize_vcs_url('https://' + control['XS-Go-Import-Path']),
             'possible')
 
 
@@ -148,11 +122,11 @@ def guess_from_setup_py(path, trust_package):
         if pkg_info.home_page:
             repo = guess_repo_from_url(pkg_info.home_page)
             if repo:
-                yield 'Repository', repo, 'possible'
+                yield 'Repository', sanitize_vcs_url(repo), 'possible'
         for value in pkg_info.project_urls:
             url_type, url = value.split(', ')
             if url_type in ('GitHub', 'Repository', 'Source Code'):
-                yield 'Repository', url, 'certain'
+                yield 'Repository', sanitize_vcs_url(url), 'certain'
 
 
 def guess_from_package_json(path, trust_package):
@@ -161,9 +135,11 @@ def guess_from_package_json(path, trust_package):
         package = json.load(f)
     if 'name' in package:
         yield 'Name', package['name'], 'certain'
+    if 'homepage' in package:
+        yield 'Homepage', package['homepage'], 'certain'
     if 'repository' in package:
         if isinstance(package['repository'], dict):
-            repo_url = package['repository']['url']
+            repo_url = package['repository'].get('url')
         elif isinstance(package['repository'], str):
             repo_url = package['repository']
         else:
@@ -171,11 +147,11 @@ def guess_from_package_json(path, trust_package):
         if repo_url:
             parsed_url = urlparse(repo_url)
             if parsed_url.scheme and parsed_url.netloc:
-                yield 'Repository', repo_url, 'certain'
+                yield 'Repository', sanitize_vcs_url(repo_url), 'certain'
             else:
                 # Some people seem to default github. :(
                 repo_url = 'https://github.com/' + parsed_url.path
-                yield 'Repository', repo_url, 'possible'
+                yield 'Repository', sanitize_vcs_url(repo_url), 'possible'
 
 
 def guess_from_package_xml(path, trust_package):
@@ -190,7 +166,7 @@ def guess_from_package_xml(path, trust_package):
         yield 'Name', name_tag.text, 'certain'
     for url_tag in root.findall('url'):
         if url_tag.get('type') == 'repository':
-            yield 'Repository', url_tag.text, 'certain'
+            yield 'Repository', sanitize_vcs_url(url_tag.text), 'certain'
         if url_tag.get('type') == 'bugtracker':
             yield 'Bug-Database', url_tag.text, 'certain'
 
@@ -246,9 +222,13 @@ def guess_from_debian_copyright(path, trust_package):
         if header.upstream_contact:
             yield "Contact", ','.join(header.upstream_contact), 'certain'
         if header.source:
-            repo_url = guess_repo_from_url(header.source)
+            if ' 'in header.source:
+                from_url = re.split('[ ,]', header.source)[0]
+            else:
+                from_url = header.source
+            repo_url = guess_repo_from_url(from_url)
             if repo_url:
-                yield 'Repository', repo_url, 'possible'
+                yield 'Repository', sanitize_vcs_url(repo_url), 'possible'
         if "X-Upstream-Bugs" in header:
             yield "Bug-Database", header["X-Upstream-Bugs"], 'certain'
         if "X-Source-Downloaded-From" in header:
@@ -263,7 +243,7 @@ def guess_from_readme(path, trust_package):
             if line.strip().startswith('git clone'):
                 line = line.strip()
                 url = line.split()[2]
-                yield ('Repository', url, 'possible')
+                yield ('Repository', sanitize_vcs_url(url), 'possible')
 
 
 def guess_from_meta_json(path, trust_package):
@@ -282,7 +262,8 @@ def guess_from_meta_json(path, trust_package):
             if 'repository' in resources:
                 repo = resources['repository']
                 if 'url' in repo:
-                    yield 'Repository', repo["url"], 'certain'
+                    yield (
+                        'Repository', sanitize_vcs_url(repo["url"]), 'certain')
                 if 'web' in repo:
                     yield 'Repository-Browse', repo['web'], 'certain'
 
@@ -305,7 +286,9 @@ def guess_from_meta_yml(path, trust_package):
             if 'homepage' in resources:
                 yield 'Homepage', resources['homepage'], 'certain'
             if 'repository' in resources:
-                yield 'Repository', resources['repository'], 'certain'
+                yield (
+                    'Repository', sanitize_vcs_url(resources['repository']),
+                    'certain')
 
 
 def guess_from_doap(path, trust_package):
@@ -346,7 +329,9 @@ def guess_from_doap(path, trust_package):
                     else:
                         repo_url = None
                     if repo_url:
-                        yield 'Repository', repo_url, 'certain'
+                        yield (
+                            'Repository', sanitize_vcs_url(repo_url),
+                            'certain')
                     web_location = repo.find(
                         '{http://usefulinc.com/ns/doap#}browse')
                     if web_location is not None:
@@ -433,3 +418,15 @@ def extend_upstream_metadata(code, certainty):
             code['Repository-Browse'] = browse_url
             certainty['Repository-Browse'] = certainty['Repository']
     # TODO(jelmer): Try deriving bug-database too?
+
+
+if __name__ == '__main__':
+    import argparse
+    import sys
+    import ruamel.yaml
+    parser = argparse.ArgumentParser(sys.argv[0])
+    parser.add_argument('path')
+    args = parser.parse_args()
+
+    metadata = guess_upstream_metadata(args.path)
+    sys.stdout.write(ruamel.yaml.round_trip_dump(metadata))
